@@ -1,9 +1,9 @@
-__version__ = '0.4.1'
-__author__ = 'PyTorchLightning et al.'
-__author_email__ = 'name@pytorchlightning.ai'
-__license__ = 'Apache-2.0'
-__copyright__ = f'Copyright (c) 2020-2021, {__author__}.'
-__homepage__ = 'https://github.com/PyTorchLightning/metrics'
+__version__ = "0.5.0"
+__author__ = "PyTorchLightning et al."
+__author_email__ = "name@pytorchlightning.ai"
+__license__ = "Apache-2.0"
+__copyright__ = f"Copyright (c) 2020-2021, {__author__}."
+__homepage__ = "https://github.com/PyTorchLightning/metrics"
 __docs__ = "PyTorch native Metrics"
 __docs_url__ = "https://torchmetrics.readthedocs.io/en/stable/"
 __long_doc__ = """
