@@ -26,9 +26,7 @@ def _binary_clf_curve(
     sample_weights: Optional[Sequence] = None,
     pos_label: int = 1,
 ) -> Tuple[Tensor, Tensor, Tensor]:
-    """
-    adapted from https://github.com/scikit-learn/scikit-learn/blob/master/sklearn/metrics/_ranking.py
-    """
+    """adapted from https://github.com/scikit-learn/scikit- learn/blob/master/sklearn/metrics/_ranking.py."""
     if sample_weights is not None and not isinstance(sample_weights, Tensor):
         sample_weights = tensor(sample_weights, device=preds.device, dtype=torch.float)
 
@@ -43,7 +41,7 @@ def _binary_clf_curve(
     if sample_weights is not None:
         weight = sample_weights[desc_score_indices]
     else:
-        weight = 1.
+        weight = 1.0
 
     # pred typically has many tied values. Here we extract
     # the indices associated with the distinct values. We also
@@ -69,17 +67,30 @@ def _precision_recall_curve_update(
     num_classes: Optional[int] = None,
     pos_label: Optional[int] = None,
 ) -> Tuple[Tensor, Tensor, int, Optional[int]]:
+    """Updates and returns variables required to compute the precision-recall pairs for different thresholds.
+
+    Args:
+        preds: Predicted tensor
+        target: Ground truth tensor
+        num_classes: integer with number of classes for multi-label and multiclass problems.
+            Should be set to ``None`` for binary problems
+        pos_label: integer determining the positive class. Default is ``None``
+            which for binary problem is translate to 1. For multiclass problems
+            this argument should not be set as we iteratively change it in the
+            range [0,num_classes-1]
+    """
+
     if len(preds.shape) == len(target.shape):
         if pos_label is None:
-            rank_zero_warn('`pos_label` automatically set 1.')
+            rank_zero_warn("`pos_label` automatically set 1.")
             pos_label = 1
         if num_classes is not None and num_classes != 1:
             # multilabel problem
             if num_classes != preds.shape[1]:
                 raise ValueError(
-                    f'Argument `num_classes` was set to {num_classes} in'
-                    f' metric `precision_recall_curve` but detected {preds.shape[1]}'
-                    ' number of classes from predictions'
+                    f"Argument `num_classes` was set to {num_classes} in"
+                    f" metric `precision_recall_curve` but detected {preds.shape[1]}"
+                    " number of classes from predictions"
                 )
             preds = preds.transpose(0, 1).reshape(num_classes, -1).transpose(0, 1)
             target = target.transpose(0, 1).reshape(num_classes, -1).transpose(0, 1)
@@ -93,14 +104,14 @@ def _precision_recall_curve_update(
     elif len(preds.shape) == len(target.shape) + 1:
         if pos_label is not None:
             rank_zero_warn(
-                'Argument `pos_label` should be `None` when running'
-                f' multiclass precision recall curve. Got {pos_label}'
+                "Argument `pos_label` should be `None` when running"
+                f" multiclass precision recall curve. Got {pos_label}"
             )
         if num_classes != preds.shape[1]:
             raise ValueError(
-                f'Argument `num_classes` was set to {num_classes} in'
-                f' metric `precision_recall_curve` but detected {preds.shape[1]}'
-                ' number of classes from predictions'
+                f"Argument `num_classes` was set to {num_classes} in"
+                f" metric `precision_recall_curve` but detected {preds.shape[1]}"
+                " number of classes from predictions"
             )
         preds = preds.transpose(0, 1).reshape(num_classes, -1).transpose(0, 1)
         target = target.flatten()
@@ -117,6 +128,15 @@ def _precision_recall_curve_compute_single_class(
     pos_label: int,
     sample_weights: Optional[Sequence] = None,
 ) -> Tuple[Tensor, Tensor, Tensor]:
+    """Computes precision-recall pairs for single class inputs.
+
+    Args:
+        preds: Predicted tensor
+        target: Ground truth tensor
+        pos_label: integer determining the positive class.
+        sample_weights: sample weights for each data point
+    """
+
     fps, tps, thresholds = _binary_clf_curve(
         preds=preds, target=target, sample_weights=sample_weights, pos_label=pos_label
     )
@@ -144,17 +164,36 @@ def _precision_recall_curve_compute_multi_class(
     num_classes: int,
     sample_weights: Optional[Sequence] = None,
 ) -> Tuple[List[Tensor], List[Tensor], List[Tensor]]:
+    """Computes precision-recall pairs for multi class inputs.
+
+    Args:
+        preds: Predicted tensor
+        target: Ground truth tensor
+        num_classes: integer with number of classes for multi-label and multiclass problems.
+            Should be set to ``None`` for binary problems
+        sample_weights: sample weights for each data point
+    """
+
     # Recursively call per class
     precision, recall, thresholds = [], [], []
     for cls in range(num_classes):
         preds_cls = preds[:, cls]
-        res = precision_recall_curve(
+
+        prc_args = dict(
             preds=preds_cls,
             target=target,
             num_classes=1,
             pos_label=cls,
             sample_weights=sample_weights,
         )
+        if target.ndim > 1:
+            prc_args.update(
+                dict(
+                    target=target[:, cls],
+                    pos_label=1,
+                )
+            )
+        res = precision_recall_curve(**prc_args)
         precision.append(res[0])
         recall.append(res[1])
         thresholds.append(res[2])
@@ -169,6 +208,51 @@ def _precision_recall_curve_compute(
     pos_label: Optional[int] = None,
     sample_weights: Optional[Sequence] = None,
 ) -> Union[Tuple[Tensor, Tensor, Tensor], Tuple[List[Tensor], List[Tensor], List[Tensor]]]:
+    """Computes precision-recall pairs based on the number of classes.
+
+    Args:
+        preds: Predicted tensor
+        target: Ground truth tensor
+        num_classes: integer with number of classes for multi-label and multiclass problems.
+            Should be set to ``None`` for binary problems
+        pos_label: integer determining the positive class. Default is ``None``
+            which for binary problem is translate to 1. For multiclass problems
+            this argument should not be set as we iteratively change it in the
+            range [0,num_classes-1]
+        sample_weights: sample weights for each data point
+
+    Example:
+        >>> # binary case
+        >>> preds = torch.tensor([0, 1, 2, 3])
+        >>> target = torch.tensor([0, 1, 1, 0])
+        >>> pos_label = 1
+        >>> preds, target, num_classes, pos_label = _precision_recall_curve_update(preds, target, pos_label=pos_label)
+        >>> precision, recall, thresholds = _precision_recall_curve_compute(preds, target, num_classes, pos_label)
+        >>> precision
+        tensor([0.6667, 0.5000, 0.0000, 1.0000])
+        >>> recall
+        tensor([1.0000, 0.5000, 0.0000, 0.0000])
+        >>> thresholds
+        tensor([1, 2, 3])
+
+        >>> # multiclass case
+        >>> preds = torch.tensor([[0.75, 0.05, 0.05, 0.05, 0.05],
+        ...                      [0.05, 0.75, 0.05, 0.05, 0.05],
+        ...                      [0.05, 0.05, 0.75, 0.05, 0.05],
+        ...                      [0.05, 0.05, 0.05, 0.75, 0.05]])
+        >>> target = torch.tensor([0, 1, 3, 2])
+        >>> num_classes = 5
+        >>> preds, target, num_classes, pos_label = _precision_recall_curve_update(preds, target, num_classes)
+        >>> precision, recall, thresholds = _precision_recall_curve_compute(preds, target, num_classes)
+        >>> precision   # doctest: +NORMALIZE_WHITESPACE
+        [tensor([1., 1.]), tensor([1., 1.]), tensor([0.2500, 0.0000, 1.0000]),
+         tensor([0.2500, 0.0000, 1.0000]), tensor([0., 1.])]
+        >>> recall
+        [tensor([1., 0.]), tensor([1., 0.]), tensor([1., 0., 0.]), tensor([1., 0., 0.]), tensor([nan, 0.])]
+        >>> thresholds
+        [tensor([0.7500]), tensor([0.7500]), tensor([0.0500, 0.7500]), tensor([0.0500, 0.7500]), tensor([0.0500])]
+    """
+
     with torch.no_grad():
         if num_classes == 1:
             if pos_label is None:
@@ -184,8 +268,7 @@ def precision_recall_curve(
     pos_label: Optional[int] = None,
     sample_weights: Optional[Sequence] = None,
 ) -> Union[Tuple[Tensor, Tensor, Tensor], Tuple[List[Tensor], List[Tensor], List[Tensor]]]:
-    """
-    Computes precision-recall pairs for different thresholds.
+    """Computes precision-recall pairs for different thresholds.
 
     Args:
         preds: predictions from model (probabilities)
