@@ -20,9 +20,7 @@ from torchmetrics.retrieval.retrieval_metric import RetrievalMetric
 
 
 class RetrievalNormalizedDCG(RetrievalMetric):
-    """
-    Computes `Normalized Discounted Cumulative Gain
-    <https://en.wikipedia.org/wiki/Discounted_cumulative_gain>`__.
+    """Computes `Normalized Discounted Cumulative Gain`_.
 
     Works with binary or positive integer target data. Accepts float predictions from a model output.
 
@@ -71,24 +69,25 @@ class RetrievalNormalizedDCG(RetrievalMetric):
 
     def __init__(
         self,
-        empty_target_action: str = 'neg',
+        empty_target_action: str = "neg",
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
         dist_sync_fn: Callable = None,
-        k: int = None
+        k: int = None,
     ) -> None:
         super().__init__(
             empty_target_action=empty_target_action,
             compute_on_step=compute_on_step,
             dist_sync_on_step=dist_sync_on_step,
             process_group=process_group,
-            dist_sync_fn=dist_sync_fn
+            dist_sync_fn=dist_sync_fn,
         )
 
         if (k is not None) and not (isinstance(k, int) and k > 0):
             raise ValueError("`k` has to be a positive integer or None")
         self.k = k
+        self.allow_non_binary_target = True
 
     def _metric(self, preds: Tensor, target: Tensor) -> Tensor:
         return retrieval_normalized_dcg(preds, target, k=self.k)
