@@ -21,16 +21,13 @@ from torchmetrics.utilities.enums import DataType
 
 
 def _check_same_shape(preds: Tensor, target: Tensor) -> None:
-    """ Check that predictions and target have the same shape, else raise error """
+    """Check that predictions and target have the same shape, else raise error."""
     if preds.shape != target.shape:
         raise RuntimeError("Predictions and targets are expected to have the same shape")
 
 
 def _basic_input_validation(preds: Tensor, target: Tensor, threshold: float, multiclass: Optional[bool]) -> None:
-    """
-    Perform basic validation of inputs that does not require deducing any information
-    of the type of inputs.
-    """
+    """Perform basic validation of inputs that does not require deducing any information of the type of inputs."""
 
     if target.is_floating_point():
         raise ValueError("The `target` has to be an integer tensor.")
@@ -52,16 +49,12 @@ def _basic_input_validation(preds: Tensor, target: Tensor, threshold: float, mul
 
 
 def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[DataType, int]:
-    """
-    This checks that the shape and type of inputs are consistent with
-    each other and fall into one of the allowed input types (see the
-    documentation of docstring of ``_input_format_classification``). It does
-    not check for consistency of number of classes, other functions take
-    care of that.
+    """This checks that the shape and type of inputs are consistent with each other and fall into one of the
+    allowed input types (see the documentation of docstring of ``_input_format_classification``). It does not check
+    for consistency of number of classes, other functions take care of that.
 
-    It returns the name of the case in which the inputs fall, and the implied
-    number of classes (from the ``C`` dim for multi-class data, or extra dim(s) for
-    multi-label data).
+    It returns the name of the case in which the inputs fall, and the implied number of classes (from the ``C`` dim for
+    multi-class data, or extra dim(s) for multi-label data).
     """
 
     preds_float = preds.is_floating_point()
@@ -114,9 +107,7 @@ def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[Da
 
 
 def _check_num_classes_binary(num_classes: int, multiclass: Optional[bool]) -> None:
-    """
-    This checks that the consistency of `num_classes` with the data and `multiclass` param for binary data.
-    """
+    """This checks that the consistency of `num_classes` with the data and `multiclass` param for binary data."""
 
     if num_classes > 2:
         raise ValueError("Your data is binary, but `num_classes` is larger than 2.")
@@ -140,10 +131,8 @@ def _check_num_classes_mc(
     multiclass: Optional[bool],
     implied_classes: int,
 ) -> None:
-    """
-    This checks that the consistency of `num_classes` with the data
-    and `multiclass` param for (multi-dimensional) multi-class data.
-    """
+    """This checks that the consistency of `num_classes` with the data and `multiclass` param for (multi-
+    dimensional) multi-class data."""
 
     if num_classes == 1 and multiclass is not False:
         raise ValueError(
@@ -162,17 +151,13 @@ def _check_num_classes_mc(
             )
         if num_classes <= target.max():
             raise ValueError("The highest label in `target` should be smaller than `num_classes`.")
-        if num_classes <= preds.max():
-            raise ValueError("The highest label in `preds` should be smaller than `num_classes`.")
         if preds.shape != target.shape and num_classes != implied_classes:
             raise ValueError("The size of C dimension of `preds` does not match `num_classes`.")
 
 
 def _check_num_classes_ml(num_classes: int, multiclass: Optional[bool], implied_classes: int) -> None:
-    """
-    This checks that the consistency of `num_classes` with the data
-    and `multiclass` param for multi-label data.
-    """
+    """This checks that the consistency of `num_classes` with the data and `multiclass` param for multi-label
+    data."""
 
     if multiclass and num_classes != 2:
         raise ValueError(
@@ -237,7 +222,7 @@ def _check_classification_inputs(
         preds: Tensor with predictions (labels or probabilities)
         target: Tensor with ground truth labels, always integers (labels)
         threshold:
-            Threshold probability value for transforming probability predictions to binary
+            Threshold value for transforming probability/logit predictions to binary
             (0,1) predictions, in the case of binary or multi-label inputs.
         num_classes:
             Number of classes. If not explicitly set, the number of classes will be inferred
@@ -300,8 +285,7 @@ def _input_squeeze(
     preds: Tensor,
     target: Tensor,
 ) -> Tuple[Tensor, Tensor]:
-    """Remove excess dimensions
-    """
+    """Remove excess dimensions."""
     if preds.shape[0] == 1:
         preds, target = preds.squeeze().unsqueeze(0), target.squeeze().unsqueeze(0)
     else:
@@ -373,7 +357,7 @@ def _input_format_classification(
         preds: Tensor with predictions (labels or probabilities)
         target: Tensor with ground truth labels, always integers (labels)
         threshold:
-            Threshold probability value for transforming probability predictions to binary
+            Threshold value for transforming probability/logit predictions to binary
             (0 or 1) predictions, in the case of binary or multi-label inputs.
         num_classes:
             Number of classes. If not explicitly set, the number of classes will be inferred
@@ -458,7 +442,7 @@ def _input_format_classification_one_hot(
     threshold: float = 0.5,
     multilabel: bool = False,
 ) -> Tuple[Tensor, Tensor]:
-    """Convert preds and target tensors into one hot spare label tensors
+    """Convert preds and target tensors into one hot spare label tensors.
 
     Args:
         num_classes: number of classes
@@ -533,7 +517,7 @@ def _check_retrieval_functional_inputs(
     if not preds.is_floating_point():
         raise ValueError("`preds` must be a tensor of floats")
 
-    if not allow_non_binary_target and target.max() > 1 or target.min() < 0:
+    if not allow_non_binary_target and (target.max() > 1 or target.min() < 0):
         raise ValueError("`target` must contain `binary` values")
 
     return preds.float().flatten(), target.long().flatten()
@@ -566,7 +550,9 @@ def _check_retrieval_inputs(
         raise ValueError("`indexes`, `preds` and `target` must be of the same shape")
 
     if not indexes.numel() or not indexes.size():
-        raise ValueError("`indexes`, `preds` and `target` must be non-empty and non-scalar tensors", )
+        raise ValueError(
+            "`indexes`, `preds` and `target` must be non-empty and non-scalar tensors",
+        )
 
     if indexes.dtype is not torch.long:
         raise ValueError("`indexes` must be a tensor of long integers")
@@ -577,7 +563,7 @@ def _check_retrieval_inputs(
     if target.dtype not in (torch.bool, torch.long, torch.int):
         raise ValueError("`target` must be a tensor of booleans or integers")
 
-    if not allow_non_binary_target and target.max() > 1 or target.min() < 0:
+    if not allow_non_binary_target and (target.max() > 1 or target.min() < 0):
         raise ValueError("`target` must contain `binary` values")
 
     return indexes.long().flatten(), preds.float().flatten(), target.long().flatten()
